Test TextBox

# Dijit TextBox Globalization Test

## Issues & Comments

### Issue #1 Not fixed. Avoid using this function of TextBox.

Strictly speaking, all casing manipulation must use ICU case mapping rules (routine). However, the default JavaScript routines used by Dojo do not support ICU case mapping rules in all browsers.

### Issue #2 Not fixed. Avoid using this function of TextBox.

Trimming must get rid of all Unicode characters with the white space property. However, the default JavaScript routines used by Dojo do not support get character properties in some browsers like IE. Other browsers like Firefox might support trimming more white space characters.